@@ -1,14 +1,14 @@
 package Inline::MakeMaker;
 
-$Inline::MakeMaker::VERSION = '0.55_02';
-$Inline::MakeMaker::VERSION = eval $Inline::MakeMaker::VERSION;
-@EXPORT = qw(WriteMakefile WriteInlineMakefile);
-
 use strict;
 use base 'Exporter';
 use ExtUtils::MakeMaker();
 use Carp;
 
+our $VERSION = "0.55_03";
+$VERSION = eval $VERSION;
+our @EXPORT = qw(WriteMakefile WriteInlineMakefile);
+
 sub WriteInlineMakefile {
 #    warn <<END;
 #
